@@ -1,19 +1,8 @@
-/***************************************************************************
-                 TestFWParser.cpp  -  K Desktop Planetarium
-                             -------------------
-    begin                : 2012/24/07
-    copyright            : (C) 2012 by Rishab Arora
-    email                : ra.rishab@gmail.com
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2012 Rishab Arora <ra.rishab@gmail.com>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "testfwparser.h"
 
