@@ -80,8 +80,8 @@
     captureDelayN->setValue((int)(delay)); \
     KTRY_CAPTURE_GADGET(QComboBox, captureTypeS); \
     KTRY_CAPTURE_COMBO_SET(captureTypeS, "Light"); \
-    KTRY_CAPTURE_GADGET(QComboBox, captureFormatS); \
-    KTRY_CAPTURE_COMBO_SET(captureFormatS, "FITS"); \
+    KTRY_CAPTURE_GADGET(QComboBox, captureEncodingS); \
+    KTRY_CAPTURE_COMBO_SET(captureEncodingS, "FITS"); \
     KTRY_CAPTURE_GADGET(QComboBox, captureFilterS); \
     KTRY_CAPTURE_COMBO_SET(captureFilterS, (filter)); \
     KTRY_CAPTURE_GADGET(QLineEdit, fileDirectoryT); \
