@@ -90,7 +90,10 @@ DarkLibrary::DarkLibrary(QWidget *parent) : QDialog(parent)
         Options::setDefectCameras(m_DefectCameras);
     });
 
-    connect(darkTableView,  &QAbstractItemView::doubleClicked, this, &DarkLibrary::loadDarkFITS);
+    connect(darkTableView,  &QAbstractItemView::doubleClicked, this, [this](QModelIndex index)
+    {
+        loadDarkImage(index.row());
+    });
     connect(openDarksFolderB, &QPushButton::clicked, this, &DarkLibrary::openDarksFolder);
     connect(clearAllB, &QPushButton::clicked, this, &DarkLibrary::clearAll);
     connect(clearRowB, &QPushButton::clicked, this, &DarkLibrary::clearRow);
@@ -161,13 +164,8 @@ DarkLibrary::DarkLibrary(QWidget *parent) : QDialog(parent)
         countDarkTotalTime();
     });
 
-    connect(startB, &QPushButton::clicked, [this]()
-    {
-        generateDarkJobs();
-        executeDarkJobs();
-    });
-
-    connect(stopB, &QPushButton::clicked, this, &DarkLibrary::stopDarkJobs);
+    connect(startB, &QPushButton::clicked, this, &DarkLibrary::start);
+    connect(stopB, &QPushButton::clicked, this, &DarkLibrary::stop);
 
     ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     // Master Darks Database Connections
@@ -211,6 +209,7 @@ DarkLibrary::DarkLibrary(QWidget *parent) : QDialog(parent)
             m_CurrentDefectMap->setProperty("HotPixelAggressiveness", aggresivenessHotSpin->value());
             m_CurrentDefectMap->setProperty("ColdPixelAggressiveness", aggresivenessColdSpin->value());
             m_CurrentDefectMap->filterPixels();
+            emit newFrame(m_DarkView);
         }
     });
     connect(resetMapParametersB, &QPushButton::clicked, [this]()
@@ -434,6 +433,7 @@ bool DarkLibrary::findDefectMap(ISD::CCDChip *m_TargetChip, double duration, QSh
     if (bestCandidate.isEmpty())
         return false;
 
+
     QString darkFilename = bestCandidate["filename"].toString();
     QString defectFilename = bestCandidate["defectmap"].toString();
 
@@ -580,14 +580,13 @@ void DarkLibrary::closeEvent(QCloseEvent *ev)
 {
     Q_UNUSED(ev)
     Options::setUseFITSViewer(m_RememberFITSViewer);
-    Options::setUseFITSViewer(m_RememberSummaryView);
-    if (!m_RememberFITSDirectory.isEmpty())
-        m_CaptureModule->fileDirectoryT->setText(m_RememberFITSDirectory);
+    Options::setUseSummaryPreview(m_RememberSummaryView);
     if (m_JobsGenerated)
     {
         m_JobsGenerated = false;
         m_CaptureModule->clearSequenceQueue();
         m_CaptureModule->setPresetSettings(m_PresetSettings);
+        m_CaptureModule->setFileSettings(m_FileSettings);
     }
 }
 
@@ -601,13 +600,12 @@ void DarkLibrary::setCompleted()
 
     Options::setUseFITSViewer(m_RememberFITSViewer);
     Options::setUseSummaryPreview(m_RememberSummaryView);
-    if (!m_RememberFITSDirectory.isEmpty())
-        m_CaptureModule->fileDirectoryT->setText(m_RememberFITSDirectory);
     if (m_JobsGenerated)
     {
         m_JobsGenerated = false;
         m_CaptureModule->clearSequenceQueue();
         m_CaptureModule->setPresetSettings(m_PresetSettings);
+        m_CaptureModule->setFileSettings(m_FileSettings);
     }
 
     m_CurrentCamera->disconnect(this);
@@ -720,12 +718,13 @@ void DarkLibrary::clearAll()
 ///////////////////////////////////////////////////////////////////////////////////////
 ///
 ///////////////////////////////////////////////////////////////////////////////////////
-void DarkLibrary::clearRow()
+void DarkLibrary::clearRow(int index)
 {
     QSqlDatabase userdb = QSqlDatabase::database("userdb");
-    int row = darkTableView->currentIndex().row();
+    if (index < 0)
+        index = darkTableView->currentIndex().row();
 
-    QSqlRecord record = darkFramesModel->record(row);
+    QSqlRecord record = darkFramesModel->record(index);
     QString filename = record.value("filename").toString();
     QString defectMap = record.value("defectmap").toString();
     QFile::remove(filename);
@@ -734,11 +733,11 @@ void DarkLibrary::clearRow()
 
     userdb.open();
 
-    darkFramesModel->removeRow(row);
+    darkFramesModel->removeRow(index);
     darkFramesModel->submitAll();
     userdb.close();
 
-    darkTableView->selectionModel()->select(darkFramesModel->index(row - 1, 0), QItemSelectionModel::ClearAndSelect);
+    darkTableView->selectionModel()->select(darkFramesModel->index(index - 1, 0), QItemSelectionModel::ClearAndSelect);
 
     refreshFromDB();
     reloadDarksFromDatabase();
@@ -944,14 +943,14 @@ void DarkLibrary::populateMasterMetedata()
 ///////////////////////////////////////////////////////////////////////////////////////
 ///
 ///////////////////////////////////////////////////////////////////////////////////////
-void DarkLibrary::loadDarkFITS(QModelIndex index)
+///////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////
+void DarkLibrary::loadDarkImage(int row)
 {
-    QSqlRecord record = darkFramesModel->record(index.row());
-
+    QSqlRecord record = darkFramesModel->record(row);
     QString filename = record.value("filename").toString();
-
-    if (filename.isEmpty() == false)
-        m_DarkView->loadFile(filename);
+    m_DarkView->loadFile(filename);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////
@@ -1061,8 +1060,8 @@ void DarkLibrary::countDarkTotalTime()
 
     //double exposureCount = (maxExposureSpin->value() - minExposureSpin->value()) / exposureStepSin->value();
     double temperatureCount = 1;
-    if (m_CurrentCamera->hasCoolerControl() && std::fabs(maxTemperatureSpin->value() - minTemperatureSpin->value()) > 0)
-        temperatureCount = (std::fabs((maxTemperatureSpin->value() - minTemperatureSpin->value())) / temperatureStepSpin->value()) +
+    if (m_CurrentCamera->hasCoolerControl() && std::abs(maxTemperatureSpin->value() - minTemperatureSpin->value()) > 0)
+        temperatureCount = (std::abs((maxTemperatureSpin->value() - minTemperatureSpin->value())) / temperatureStepSpin->value()) +
                            1;
     int binnings = 0;
     if (bin1Check->isChecked())
@@ -1099,6 +1098,7 @@ void DarkLibrary::generateDarkJobs()
     {
         m_JobsGenerated = true;
         m_PresetSettings = m_CaptureModule->getPresetSettings();
+        m_FileSettings = m_CaptureModule->getFileSettings();
     }
 
     QList<double> temperatures;
@@ -1155,7 +1155,7 @@ void DarkLibrary::generateDarkJobs()
                 settings["bin"] = oneBin;
                 settings["frameType"] = FRAME_DARK;
                 settings["temperature"] = oneTemperature;
-                settings["format"] = 0;
+                settings["transferFormat"] = 0;
 
                 QString directory = prefix + QString("sequence_%1").arg(sequence);
                 QJsonObject fileSettings;
@@ -1173,7 +1173,7 @@ void DarkLibrary::generateDarkJobs()
 ///////////////////////////////////////////////////////////////////////////////////////
 ///
 ///////////////////////////////////////////////////////////////////////////////////////
-void DarkLibrary::executeDarkJobs()
+void DarkLibrary::execute()
 {
     m_DarkImagesCounter = 0;
     darkProgress->setValue(0);
@@ -1195,7 +1195,7 @@ void DarkLibrary::executeDarkJobs()
 ///////////////////////////////////////////////////////////////////////////////////////
 ///
 ///////////////////////////////////////////////////////////////////////////////////////
-void DarkLibrary::stopDarkJobs()
+void DarkLibrary::stop()
 {
     m_CaptureModule->abort();
     darkProgress->setValue(0);
@@ -1214,7 +1214,10 @@ void DarkLibrary::initView()
     QVBoxLayout *vlayout = new QVBoxLayout();
     vlayout->addWidget(m_DarkView);
     darkWidget->setLayout(vlayout);
-    //connect(m_DarkView, &FITSView::loaded, this, &DarkLibrary::loadCurrentMasterDefectMap);
+    connect(m_DarkView, &DarkView::loaded, this, [this]()
+    {
+        emit newImage(m_DarkView->imageData());
+    });
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////
@@ -1315,8 +1318,10 @@ void DarkLibrary::generateMasterFrame(const QSharedPointer<FITSData> &data, cons
             break;
     }
 
+    emit newImage(data);
     // Reset Master Buffer
     m_DarkMasterBuffer.assign(m_DarkMasterBuffer.size(), 0);
+
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////
@@ -1333,7 +1338,8 @@ template <typename T>  void DarkLibrary::generateMasterFrameInternal(const QShar
 
 
     QString ts = QDateTime::currentDateTime().toString("yyyy-MM-ddThh-mm-ss");
-    QString path = QDir(KSPaths::writableLocation(QStandardPaths::AppLocalDataLocation)).filePath("darks/darkframe_" + ts + ".fits");
+    QString path = QDir(KSPaths::writableLocation(QStandardPaths::AppLocalDataLocation)).filePath("darks/darkframe_" + ts +
+                   ".fits");
 
     data->calculateStats(true);
     if (!data->saveImage(path))
@@ -1364,7 +1370,6 @@ template <typename T>  void DarkLibrary::generateMasterFrameInternal(const QShar
 void DarkLibrary::setCaptureModule(Capture *instance)
 {
     m_CaptureModule = instance;
-    m_RememberFITSDirectory = m_CaptureModule->fileDirectoryT->text();
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////
@@ -1430,5 +1435,165 @@ void DarkLibrary::saveDefectMap()
     }
 }
 
+///////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////
+void DarkLibrary::start()
+{
+    generateDarkJobs();
+    execute();
+}
+
+void DarkLibrary::setDarkSettings(const QJsonObject &settings)
+{
+    const QString camera = settings["camera"].toString();
+    const double minExposure = settings["minExposure"].toDouble(minExposureSpin->value());
+    const double maxExposure = settings["maxExposure"].toDouble(maxExposureSpin->value());
+    const double minTemperature = settings["minTemperature"].toDouble(minTemperatureSpin->value());
+    const double maxTemperature = settings["maxTemperature"].toDouble(maxTemperatureSpin->value());
+    const bool binOneCheck = settings["BinOne"].toBool(bin1Check->isChecked());
+    const bool binTwoCheck = settings["BinTwo"].toBool(bin2Check->isChecked());
+    const bool binFourCheck = settings["BinFour"].toBool(bin4Check->isChecked());
+    const int count = settings["count"].toInt(countSpin->value());
+
+    cameraS->setCurrentText(camera);
+    bin1Check->setChecked(binOneCheck);
+    bin2Check->setChecked(binTwoCheck);
+    bin4Check->setChecked(binFourCheck);
+
+    minExposureSpin->setValue(minExposure);
+    maxExposureSpin->setValue(maxExposure);
+
+    if (minTemperatureSpin->isEnabled())
+        minTemperatureSpin->setValue(minTemperature);
+    if (maxTemperatureSpin->isEnabled())
+        maxTemperatureSpin->setValue(maxTemperature);
+    countSpin->setValue(count);
+
+}
+
+QJsonObject DarkLibrary::getDarkSettings()
+{
+    QJsonObject createDarks =
+    {
+        {"camera", cameraS->currentText()},
+        {"minExposureValue", minExposureSpin->value()},
+        {"maxExposureValue", maxExposureSpin->value()},
+        {"minTemperatureValue", minTemperatureSpin->value()},
+        {"maxTemperatureValue", maxTemperatureSpin->value()},
+        {"temperatureEnabled", minTemperatureSpin->isEnabled()},
+        {"bin1Check", bin1Check->isChecked()},
+        {"bin2Check", bin2Check->isChecked()},
+        {"bin4Check", bin4Check->isChecked()},
+        {"countSpin", countSpin->value()},
+        {"totalImages", totalImages->text()},
+        {"totalTime", totalTime->text()},
+        {"darkProgress", darkProgress->value()}
+    };
+    return createDarks;
+}
+
+void DarkLibrary::setCameraPresets(const QJsonObject &settings)
+{
+    const QString camera = settings["camera"].toString();
+    const bool isDarkPrefer = settings["isDarkPrefer"].toBool(preferDarksRadio->isChecked());
+    const bool isDefectPrefer = settings["isDefectPrefer"].toBool(preferDefectsRadio->isChecked());
+    cameraS->setCurrentText(camera);
+    preferDarksRadio->setChecked(isDarkPrefer);
+    preferDefectsRadio->setChecked(isDefectPrefer);
+    checkCamera();
+    reloadDarksFromDatabase();
+}
+
+QJsonObject DarkLibrary::getCameraPresets()
+{
+    QJsonObject cameraSettings =
+    {
+        {"camera", cameraS->currentText()},
+        {"preferDarksRadio", preferDarksRadio->isChecked()},
+        {"preferDefectsRadio", preferDefectsRadio->isChecked()},
+        {"fileName", m_FileLabel->text()}
+    };
+    return cameraSettings;
+}
+
+QJsonObject DarkLibrary::getDefectSettings()
+{
+    QJsonObject createDefectMaps =
+    {
+        {"masterTime", masterTime->text()},
+        {"masterExposure", masterExposure->text()},
+        {"masterTempreture", masterTemperature->text()},
+        {"masterMean", masterMean->text()},
+        {"masterMedian", masterMedian->text()},
+        {"masterDeviation", masterDeviation->text()},
+        {"hotPixelsCount", hotPixelsCount->value()},
+        {"coldPixelsCount", coldPixelsCount->value()},
+        {"aggresivenessHotSpin", aggresivenessHotSpin->value()},
+        {"aggresivenessColdSpin", aggresivenessColdSpin->value()},
+        {"hotPixelsEnabled", hotPixelsEnabled->isChecked()},
+        {"coldPixelsEnabled", coldPixelsEnabled->isChecked()},
+    };
+    return createDefectMaps;
+}
+
+QJsonArray DarkLibrary::getViewMasters()
+{
+    QJsonArray array;
+    int binX, binY;
+    double temperature, duration;
+    QString camera, ts;
+
+    for(int i = 0; i < darkFramesModel->rowCount(); i++)
+    {
+        QSqlRecord record = darkFramesModel->record(i);
+        camera = record.value("ccd").toString();
+        binX = record.value("binX").toInt();
+        binY = record.value("binY").toInt();
+        temperature = record.value("temperature").toDouble();
+        duration = record.value("duration").toDouble();
+        ts = record.value("timestamp").toString();
+
+        QJsonObject filterRows =
+        {
+            {"camera", camera},
+            {"binX", binX},
+            {"binY", binY},
+            {"temperature", temperature},
+            {"duaration", duration},
+            {"ts", ts}
+        };
+        array.append(filterRows);
+    }
+    return array;
+}
+
+void DarkLibrary::setDefectSettings(const QJsonObject payload)
+{
+    const int masterIndex = payload["rowIndex"].toInt();
+    masterDarksCombo->setCurrentIndex(masterIndex);
+}
+
+void DarkLibrary::setDefectPixels(const QJsonObject &payload)
+{
+    const int hotSpin = payload["hotSpin"].toInt();
+    const int coldSpin = payload["coldSpin"].toInt();
+    const bool hotEnabled = payload["hotEnabled"].toBool(hotPixelsEnabled->isChecked());
+    const bool coldEnabled = payload["coldEnabled"].toBool(coldPixelsEnabled->isChecked());
+
+    hotPixelsEnabled->setChecked(hotEnabled);
+    coldPixelsEnabled->setChecked(coldEnabled);
+
+    aggresivenessHotSpin->setValue(hotSpin);
+    aggresivenessColdSpin->setValue(coldSpin);
+
+    setDefectFrame(true);
+    generateMapB->click();
+}
+
+void DarkLibrary::setDefectFrame(bool isDefect)
+{
+    m_DarkView->setDefectMapEnabled(isDefect);
+}
 }
 
