@@ -91,24 +91,44 @@ class DarkLibrary : public QDialog, public Ui::DarkLibrary
         //void reset();
         void setCaptureModule(Capture *instance);
 
+        void start();
+        void setDarkSettings(const QJsonObject &settings);
+        void setCameraPresets(const QJsonObject &settings);
+        QJsonObject getCameraPresets();
+        QJsonObject getDarkSettings();
+        QJsonObject getDefectSettings();
+        void setDefectPixels(const QJsonObject &payload);
+        QJsonArray getViewMasters();
+        void getloadDarkViewMasterFITS(int index);
+        void setDefectSettings(const QJsonObject row);
+        void setDefectFrame(bool isDefect);
+
+        /**
+         * @brief stop Abort all dark job captures.
+         */
+        void stop();
     protected:
         virtual void closeEvent(QCloseEvent *ev) override;
 
     signals:
         void newLog(const QString &message);
+        void newImage(const QSharedPointer<FITSData> &data);
+        void newFrame(FITSView *view);
 
     public slots:
         void processNewImage(SequenceJob *job, const QSharedPointer<FITSData> &data);
         void processNewBLOB(IBLOB *bp);
+        void loadDarkImage(int row);
+        void clearRow(int row = -1);
+
 
     private slots:
         void clearAll();
-        void clearRow();
         void clearExpired();
         void openDarksFolder();
         void saveDefectMap();
         void setCompleted();
-        void loadDarkFITS(QModelIndex index);
+
 
     private:
         explicit DarkLibrary(QWidget *parent);
@@ -132,14 +152,9 @@ class DarkLibrary : public QDialog, public Ui::DarkLibrary
         void generateDarkJobs();
 
         /**
-         * @brief executeDarkJobs Start executing the dark jobs in capture module.
+         * @brief execute Start executing the dark jobs in capture module.
          */
-        void executeDarkJobs();
-
-        /**
-         * @brief stopDarkJobs Abort all dark job captures.
-         */
-        void stopDarkJobs();
+        void execute();
 
         /**
          * @brief generateMasterFrameHelper Calls templated generateMasterFrame with the correct data type.
@@ -222,9 +237,8 @@ class DarkLibrary : public QDialog, public Ui::DarkLibrary
         uint32_t m_DarkImagesCounter {0};
         bool m_RememberFITSViewer {true};
         bool m_RememberSummaryView {true};
-        QString m_RememberFITSDirectory;
         bool m_JobsGenerated {false};
-        QJsonObject m_PresetSettings;
+        QJsonObject m_PresetSettings, m_FileSettings;
         QString m_DefectMapFilename, m_MasterDarkFrameFilename;
         QStringList m_DarkCameras, m_DefectCameras;
         QPointer<DarkView> m_DarkView;
