@@ -7,6 +7,8 @@
 #pragma once
 
 #include "ui_capture.h"
+#include "capturecommandprocessor.h"
+#include "sequencejobstate.h"
 #include "customproperties.h"
 #include "oal/filter.h"
 #include "ekos/ekos.h"
@@ -92,31 +94,6 @@ class Capture : public QWidget, public Ui::Capture
 
     public:
         typedef enum { MF_NONE, MF_REQUESTED, MF_READY, MF_INITIATED, MF_FLIPPING, MF_SLEWING, MF_COMPLETED, MF_ALIGNING, MF_GUIDING } MFStage;
-        typedef enum
-        {
-            CAL_NONE,
-            CAL_DUSTCAP_PARKING,
-            CAL_DUSTCAP_PARKED,
-            CAL_LIGHTBOX_ON,
-            CAL_SLEWING,
-            CAL_SLEWING_COMPLETE,
-            CAL_MOUNT_PARKING,
-            CAL_MOUNT_PARKED,
-            CAL_DOME_PARKING,
-            CAL_DOME_PARKED,
-            CAL_PRECAPTURE_COMPLETE,
-            CAL_CALIBRATION,
-            CAL_CALIBRATION_COMPLETE,
-            CAL_CAPTURING,
-            CAL_DUSTCAP_UNPARKING,
-            CAL_DUSTCAP_UNPARKED
-        } CalibrationStage;
-
-        typedef enum
-        {
-            CAL_CHECK_TASK,
-            CAL_CHECK_CONFIRMATION,
-        } CalibrationCheckType;
 
         typedef enum
         {
@@ -312,18 +289,9 @@ class Capture : public QWidget, public Ui::Capture
 
         void addCCD(ISD::GDInterface *newCCD);
         void addFilter(ISD::GDInterface *newFilter);
-        void setDome(ISD::GDInterface *device)
-        {
-            currentDome = dynamic_cast<ISD::Dome *>(device);
-        }
-        void setDustCap(ISD::GDInterface *device)
-        {
-            currentDustCap = dynamic_cast<ISD::DustCap *>(device);
-        }
-        void setLightBox(ISD::GDInterface *device)
-        {
-            currentLightBox = dynamic_cast<ISD::LightBox *>(device);
-        }
+        void setDome(ISD::GDInterface *device);
+        void setDustCap(ISD::GDInterface *device);
+        void setLightBox(ISD::GDInterface *device);
         void removeDevice(ISD::GDInterface *device);
         void addGuideHead(ISD::GDInterface *newCCD);
         void syncFrameType(ISD::GDInterface *ccd);
@@ -620,8 +588,9 @@ class Capture : public QWidget, public Ui::Capture
          * @brief removeJob Remove a job sequence from the queue
          * @param index Row index for job to remove, if left as -1 (default), the currently selected row will be removed.
          *        if no row is selected, the last job shall be removed.
+         * @param true if sequence is removed. False otherwise.
          */
-        void removeJob(int index = -1);
+        bool removeJob(int index = -1);
 
         void removeJobFromQueue();
 
@@ -720,6 +689,11 @@ class Capture : public QWidget, public Ui::Capture
          */
         void registerNewModule(const QString &name);
 
+        /**
+         * @brief generateDarkFlats Generate a list of dark flat jobs from available flat frames.
+         */
+        void generateDarkFlats();
+
     private slots:
 
         /**
@@ -781,15 +755,6 @@ class Capture : public QWidget, public Ui::Capture
          */
         IPState checkLightFramePendingTasks();
 
-        /**
-         * @brief Check whether the scope cover is removed (manual cover, flat covers, dark covers etc.)
-         * @return true iff scope cover is open
-         */
-        IPState checkLightFrameScopeCoverOpen();
-
-        IPState checkFlatFramePendingTasks();
-        IPState checkDarkFramePendingTasks();
-
         // Send image info
         //void sendNewImage(const QString &filename, ISD::CCDChip *myChip);
 
@@ -820,7 +785,7 @@ class Capture : public QWidget, public Ui::Capture
         Q_SCRIPTABLE void meridianFlipStarted();
         Q_SCRIPTABLE void meridianFlipCompleted();
         Q_SCRIPTABLE void newStatus(Ekos::CaptureState status);
-        Q_SCRIPTABLE void newSequenceImage(const QString &filename, const QString &previewFITS);
+        Q_SCRIPTABLE void captureComplete(const QVariantMap &metadata);
 
         void ready();
 
@@ -828,6 +793,7 @@ class Capture : public QWidget, public Ui::Capture
         void prepareCapture();
 
         // device status
+        void setGuiderActive(bool active);
         void newGuiderDrift(double deviation_rms);
         void newRotatorAngle(double value, IPState state);
         void newTemperatureValue(double value);
@@ -848,9 +814,7 @@ class Capture : public QWidget, public Ui::Capture
         void dslrInfoRequested(const QString &cameraName);
         void driverTimedout(const QString &deviceName);
 
-        // Signals for the Analyze tab.
-        void captureComplete(const QString &filename, double exposureSeconds, const QString &filter,
-                             double hfr, int numStars, int median, double eccentricity);
+        // Signals for the Analyze tab.        
         void captureStarting(double exposureSeconds, const QString &filter);
         void captureAborted(double exposureSeconds);
 
@@ -988,11 +952,6 @@ class Capture : public QWidget, public Ui::Capture
          */
         void processCaptureError(ISD::CCD::ErrorType type);
 
-        /**
-         * @brief generateDarkFlats Generate a list of dark flat jobs from available flat frames.
-         */
-        void generateDarkFlats();
-
         /**
          * @brief setDarkFlatExposure Given a dark flat job, find the exposure suitable from it by searching for
          * completed flat frames.
@@ -1037,6 +996,8 @@ class Capture : public QWidget, public Ui::Capture
         // Currently active sequence job.
         // DO NOT SET IT MANUALLY, USE {@see setActiveJob()} INSTEAD!
         SequenceJob *activeJob { nullptr };
+        QSharedPointer<CaptureCommandProcessor> m_commandProcessor;
+        QSharedPointer<SequenceJobState::CaptureState> m_captureState;
 
         QList<ISD::CCD *> CCDs;
 
@@ -1119,12 +1080,8 @@ class Capture : public QWidget, public Ui::Capture
         bool preDomePark { false };
         FlatFieldDuration flatFieldDuration { DURATION_MANUAL };
         FlatFieldSource flatFieldSource { SOURCE_MANUAL };
-        CalibrationStage calibrationStage { CAL_NONE };
-        CalibrationCheckType calibrationCheckType { CAL_CHECK_TASK };
         bool dustCapLightEnabled { false };
         bool lightBoxLightEnabled { false };
-        bool m_TelescopeCoveredDarkExposure { false };
-        bool m_TelescopeCoveredFlatExposure { false };
         QMap<ScriptTypes, QString> m_Scripts;
 
         QUrl dirPath;
@@ -1186,6 +1143,7 @@ class Capture : public QWidget, public Ui::Capture
         QList<double> downloadTimes;
         QElapsedTimer m_DownloadTimer;
         QTimer downloadProgressTimer;
+        QVariantMap m_Metadata;
         void processGuidingFailed();
 };
 }
