@@ -27,25 +27,9 @@ const QStringList SequenceJob::StatusStrings = QStringList() << i18n("Idle") <<
         i18n("Aborted")
         << i18n("Complete");
 
-/**
- * @brief SequenceJob::SequenceJob Default Constructor
- */
+
 SequenceJob::SequenceJob()
 {
-    // signal forwarding between this and the state machine
-    connect(this, &SequenceJob::prepareCapture, &stateMachine, &SequenceJobState::prepareCapture);
-    connect(this, &SequenceJob::updateCCDTemperature, &stateMachine, &SequenceJobState::setCurrentCCDTemperature);
-    connect(this, &SequenceJob::updateRotatorAngle, &stateMachine, &SequenceJobState::setCurrentRotatorAngle);
-    connect(this, &SequenceJob::updateGuiderDrift, &stateMachine, &SequenceJobState::setCurrentGuiderDrift);
-    connect(&stateMachine, &SequenceJobState::readCurrentState, this, &SequenceJob::readCurrentState);
-    connect(&stateMachine, &SequenceJobState::prepareState, this, &SequenceJob::prepareState);
-    connect(&stateMachine, &SequenceJobState::prepareComplete, this, &SequenceJob::prepareComplete);
-    // connect state machine with command processor
-    connect(&stateMachine, &SequenceJobState::setRotatorAngle, &commandProcessor, &CaptureCommandProcessor::setRotatorAngle);
-    connect(&stateMachine, &SequenceJobState::setCCDTemperature, &commandProcessor,
-            &CaptureCommandProcessor::setCCDTemperature);
-    connect(&stateMachine, &SequenceJobState::setCCDBatchMode, &commandProcessor, &CaptureCommandProcessor::enableCCDBatchMode);
-
     // Set default property values
     m_CoreProperties[SJ_Exposure] = -1;
     m_CoreProperties[SJ_Gain] = -1;
@@ -61,6 +45,26 @@ SequenceJob::SequenceJob()
     m_CoreProperties[SJ_FilterPrefixEnabled] = false;
     m_CoreProperties[SJ_DarkFlat] = false;
     m_CoreProperties[SJ_GuiderActive] = false;
+    m_CoreProperties[SJ_Encoding] = "FITS";
+}
+
+SequenceJob::SequenceJob(const QSharedPointer<CaptureCommandProcessor> cp,
+                         const QSharedPointer<SequenceJobState::CaptureState> sharedState) : SequenceJob()
+{
+    commandProcessor = cp;
+    // initialize the state machine
+    stateMachine = new SequenceJobState(sharedState);
+
+    // signal forwarding between this and the state machine
+    connect(this, &SequenceJob::updateCCDTemperature, stateMachine, &SequenceJobState::setCurrentCCDTemperature);
+    connect(this, &SequenceJob::updateRotatorAngle, stateMachine, &SequenceJobState::setCurrentRotatorAngle);
+    connect(this, &SequenceJob::setGuiderActive, stateMachine, &SequenceJobState::setGuiderActive);
+    connect(this, &SequenceJob::updateGuiderDrift, stateMachine, &SequenceJobState::setCurrentGuiderDrift);
+    connect(stateMachine, &SequenceJobState::readCurrentState, this, &SequenceJob::readCurrentState);
+    connect(stateMachine, &SequenceJobState::prepareState, this, &SequenceJob::prepareState);
+    connect(stateMachine, &SequenceJobState::prepareComplete, this, &SequenceJob::processPrepareComplete);
+    connect(stateMachine, &SequenceJobState::abortCapture, this, &SequenceJob::processAbortCapture);
+    connect(stateMachine, &SequenceJobState::newLog, this, &SequenceJob::newLog);
 }
 
 /**
@@ -72,6 +76,11 @@ SequenceJob::SequenceJob(XMLEle *root): SequenceJob()
     XMLEle *ep    = nullptr;
     XMLEle *subEP = nullptr;
 
+    // set own unconnected state machine
+    QSharedPointer<SequenceJobState::CaptureState> sharedState;
+    sharedState.reset(new SequenceJobState::CaptureState);
+    stateMachine = new SequenceJobState(sharedState);
+
     // We expect all data read from the XML to be in the C locale - QLocale::c().
     QLocale cLocale = QLocale::c();
 
@@ -95,6 +104,14 @@ SequenceJob::SequenceJob(XMLEle *root): SequenceJob()
         {
             setCoreProperty(SJ_Exposure, atof(pcdataXMLEle(ep)));
         }
+        if (!strcmp(tagXMLEle(ep), "Format"))
+        {
+            setCoreProperty(SJ_Format, pcdataXMLEle(ep));
+        }
+        if (!strcmp(tagXMLEle(ep), "Encoding"))
+        {
+            setCoreProperty(SJ_Encoding, pcdataXMLEle(ep));
+        }
         else if (!strcmp(tagXMLEle(ep), "Filter"))
         {
             setCoreProperty(SJ_Filter, QString(pcdataXMLEle(ep)));
@@ -213,33 +230,49 @@ SequenceJob::SequenceJob(XMLEle *root): SequenceJob()
             subEP = findXMLEle(ep, "PreMountPark");
             if (subEP)
             {
-                setCoreProperty(SJ_PreMountPark, (!strcmp(pcdataXMLEle(subEP), "True")));
+                setPreMountPark(!strcmp(pcdataXMLEle(subEP), "True"));
             }
 
             subEP = findXMLEle(ep, "PreDomePark");
             if (subEP)
             {
-                setCoreProperty(SJ_PreDomePark, (!strcmp(pcdataXMLEle(subEP), "True")));
+                setPreDomePark(!strcmp(pcdataXMLEle(subEP), "True"));
             }
         }
     }
 }
 
-void SequenceJob::resetStatus()
+void SequenceJob::resetStatus(JOBStatus status)
 {
-    setStatus(JOB_IDLE);
-    setCompleted(0);
-    m_ExposeLeft     = 0;
-    m_CaptureRetires = 0;
-    m_JobProgressIgnored = false;
+    setStatus(status);
+    setCalibrationStage(SequenceJobState::CAL_NONE);
+    switch (status)
+    {
+        case JOB_IDLE:
+            setCompleted(0);
+            // 2022.03.10: Keeps failing on Windows despite installing latest libindi
+#ifndef Q_OS_WIN
+            INDI_FALLTHROUGH;
+#endif
+        case JOB_ERROR:
+        case JOB_ABORTED:
+        case JOB_DONE:
+            m_ExposeLeft     = 0;
+            m_CaptureRetires = 0;
+            m_JobProgressIgnored = false;
+            break;
+        case JOB_BUSY:
+            // do nothing
+            break;
+    }
 }
 
 void SequenceJob::abort()
 {
     setStatus(JOB_ABORTED);
-    if (commandProcessor.activeChip->canAbort())
-        commandProcessor.activeChip->abortExposure();
-    commandProcessor.activeChip->setBatchMode(false);
+    if (commandProcessor.data()->activeChip->canAbort())
+        commandProcessor.data()->activeChip->abortExposure();
+    commandProcessor.data()->activeChip->setBatchMode(false);
 }
 
 void SequenceJob::done()
@@ -267,7 +300,7 @@ int SequenceJob::getJobRemainingTime(double estimatedDownloadTime)
 
 void SequenceJob::setStatus(JOBStatus const in_status)
 {
-    stateMachine.reset(in_status);
+    stateMachine->reset(in_status);
     if( !getCoreProperty(SequenceJob::SJ_Preview).toBool() && nullptr != statusCell)
         statusCell->setText(StatusStrings[in_status]);
 }
@@ -338,29 +371,78 @@ void SequenceJob::setScript(ScriptTypes type, const QString &value)
     m_Scripts[type] = value;
 }
 
+void SequenceJob::connectCommandProcessor()
+{
+    connect(stateMachine, &SequenceJobState::setRotatorAngle, commandProcessor.data(),
+            &CaptureCommandProcessor::setRotatorAngle);
+    connect(stateMachine, &SequenceJobState::setCCDTemperature, commandProcessor.data(),
+            &CaptureCommandProcessor::setCCDTemperature);
+    connect(stateMachine, &SequenceJobState::setCCDBatchMode, commandProcessor.data(),
+            &CaptureCommandProcessor::enableCCDBatchMode);
+    connect(stateMachine, &SequenceJobState::askManualScopeLightCover, commandProcessor.data(),
+            &CaptureCommandProcessor::askManualScopeLightCover);
+    connect(stateMachine, &SequenceJobState::askManualScopeLightOpen, commandProcessor.data(),
+            &CaptureCommandProcessor::askManualScopeLightOpen);
+    connect(stateMachine, &SequenceJobState::setLightBoxLight, commandProcessor.data(),
+            &CaptureCommandProcessor::setLightBoxLight);
+    connect(stateMachine, &SequenceJobState::setDustCapLight, commandProcessor.data(),
+            &CaptureCommandProcessor::setDustCapLight);
+    connect(stateMachine, &SequenceJobState::parkDustCap, commandProcessor.data(), &CaptureCommandProcessor::parkDustCap);
+    connect(stateMachine, &SequenceJobState::slewTelescope, commandProcessor.data(), &CaptureCommandProcessor::slewTelescope);
+    connect(stateMachine, &SequenceJobState::setScopeTracking, commandProcessor.data(),
+            &CaptureCommandProcessor::setScopeTracking);
+    connect(stateMachine, &SequenceJobState::setScopeParked, commandProcessor.data(), &CaptureCommandProcessor::setScopeParked);
+    connect(stateMachine, &SequenceJobState::setDomeParked, commandProcessor.data(), &CaptureCommandProcessor::setDomeParked);
+    connect(stateMachine, &SequenceJobState::flatSyncFocus, commandProcessor.data(), &CaptureCommandProcessor::flatSyncFocus);
+    connect(stateMachine, &SequenceJobState::queryHasShutter, commandProcessor.data(),
+            &CaptureCommandProcessor::queryHasShutter);
+    // connect command processor with state machine
+    connect(commandProcessor.data(), &CaptureCommandProcessor::manualScopeLightCover, stateMachine,
+            &SequenceJobState::manualScopeLightCover);
+    connect(commandProcessor.data(), &CaptureCommandProcessor::lightBoxLight, stateMachine, &SequenceJobState::lightBoxLight);
+    connect(commandProcessor.data(), &CaptureCommandProcessor::dustCapLight, stateMachine, &SequenceJobState::dustCapLight);
+    connect(commandProcessor.data(), &CaptureCommandProcessor::dustCapStatusChanged, stateMachine,
+            &SequenceJobState::dustCapStatusChanged);
+    connect(commandProcessor.data(), &CaptureCommandProcessor::scopeStatusChanged, stateMachine,
+            &SequenceJobState::scopeStatusChanged);
+    connect(commandProcessor.data(), &CaptureCommandProcessor::scopeParkStatusChanged, stateMachine,
+            &SequenceJobState::scopeParkStatusChanged);
+    connect(commandProcessor.data(), &CaptureCommandProcessor::domeStatusChanged, stateMachine,
+            &SequenceJobState::domeStatusChanged);
+    connect(commandProcessor.data(), &CaptureCommandProcessor::flatSyncFocusChanged, stateMachine,
+            &SequenceJobState::flatSyncFocusChanged);
+    connect(commandProcessor.data(), &CaptureCommandProcessor::hasShutter, stateMachine, &SequenceJobState::hasShutter);
+}
+
+void SequenceJob::disconnectCommandProcessor()
+{
+    disconnect(stateMachine, nullptr, commandProcessor.data(), nullptr);
+    disconnect(commandProcessor.data(), nullptr, stateMachine, nullptr);
+}
+
 CAPTUREResult SequenceJob::capture(bool autofocusReady, FITSMode mode)
 {
-    commandProcessor.activeChip->setBatchMode(!getCoreProperty(SequenceJob::SJ_Preview).toBool());
-    commandProcessor.activeCCD->setISOMode(getCoreProperty(SJ_TimeStampPrefixEnabled).toBool());
-    commandProcessor.activeCCD->setSeqPrefix(getCoreProperty(SJ_FullPrefix).toString());
+    commandProcessor.data()->activeChip->setBatchMode(!getCoreProperty(SequenceJob::SJ_Preview).toBool());
+    commandProcessor.data()->activeCCD->setISOMode(getCoreProperty(SJ_TimeStampPrefixEnabled).toBool());
+    commandProcessor.data()->activeCCD->setSeqPrefix(getCoreProperty(SJ_FullPrefix).toString());
 
     auto placeholderPath = Ekos::PlaceholderPath(getCoreProperty(SJ_LocalDirectory).toString() + "/sequence.esq");
     placeholderPath.setGenerateFilenameSettings(*this);
-    commandProcessor.activeCCD->setPlaceholderPath(placeholderPath);
+    commandProcessor.data()->activeCCD->setPlaceholderPath(placeholderPath);
 
     if (getCoreProperty(SequenceJob::SJ_Preview).toBool())
     {
-        if (commandProcessor.activeCCD->getUploadMode() != ISD::CCD::UPLOAD_CLIENT)
-            commandProcessor.activeCCD->setUploadMode(ISD::CCD::UPLOAD_CLIENT);
+        if (commandProcessor.data()->activeCCD->getUploadMode() != ISD::CCD::UPLOAD_CLIENT)
+            commandProcessor.data()->activeCCD->setUploadMode(ISD::CCD::UPLOAD_CLIENT);
     }
     else
-        commandProcessor.activeCCD->setUploadMode(m_UploadMode);
+        commandProcessor.data()->activeCCD->setUploadMode(m_UploadMode);
 
     QMapIterator<QString, QMap<QString, QVariant>> i(m_CustomProperties);
     while (i.hasNext())
     {
         i.next();
-        INDI::Property *customProp = commandProcessor.activeCCD->getProperty(i.key());
+        INDI::Property *customProp = commandProcessor.data()->activeCCD->getProperty(i.key());
         if (customProp)
         {
             QMap<QString, QVariant> elements = i.value();
@@ -378,7 +460,7 @@ CAPTUREResult SequenceJob::capture(bool autofocusReady, FITSMode mode)
                         if (oneSwitch)
                             oneSwitch->setState(static_cast<ISState>(j.value().toInt()));
                     }
-                    commandProcessor.activeCCD->getDriverInfo()->getClientManager()->sendNewSwitch(sp);
+                    commandProcessor.data()->activeCCD->getDriverInfo()->getClientManager()->sendNewSwitch(sp);
                 }
                 break;
                 case INDI_TEXT:
@@ -391,7 +473,7 @@ CAPTUREResult SequenceJob::capture(bool autofocusReady, FITSMode mode)
                         if (oneText)
                             oneText->setText(j.value().toString().toLatin1().constData());
                     }
-                    commandProcessor.activeCCD->getDriverInfo()->getClientManager()->sendNewText(tp);
+                    commandProcessor.data()->activeCCD->getDriverInfo()->getClientManager()->sendNewText(tp);
                 }
                 break;
                 case INDI_NUMBER:
@@ -404,7 +486,7 @@ CAPTUREResult SequenceJob::capture(bool autofocusReady, FITSMode mode)
                         if (oneNumber)
                             oneNumber->setValue(j.value().toDouble());
                     }
-                    commandProcessor.activeCCD->getDriverInfo()->getClientManager()->sendNewNumber(np);
+                    commandProcessor.data()->activeCCD->getDriverInfo()->getClientManager()->sendNewNumber(np);
                 }
                 break;
                 default:
@@ -414,31 +496,31 @@ CAPTUREResult SequenceJob::capture(bool autofocusReady, FITSMode mode)
     }
 
     const auto remoteDirectory = getCoreProperty(SJ_RemoteDirectory).toString();
-    if (commandProcessor.activeChip->isBatchMode() && remoteDirectory.isEmpty() == false)
-        commandProcessor.activeCCD->updateUploadSettings(remoteDirectory + getCoreProperty(SJ_DirectoryPostfix).toString());
+    if (commandProcessor.data()->activeChip->isBatchMode() && remoteDirectory.isEmpty() == false)
+        commandProcessor.data()->activeCCD->updateUploadSettings(remoteDirectory + getCoreProperty(SJ_DirectoryPostfix).toString());
 
     const int ISOIndex = getCoreProperty(SJ_ISOIndex).toInt();
     if (ISOIndex != -1)
     {
-        if (ISOIndex != commandProcessor.activeChip->getISOIndex())
-            commandProcessor.activeChip->setISOIndex(ISOIndex);
+        if (ISOIndex != commandProcessor.data()->activeChip->getISOIndex())
+            commandProcessor.data()->activeChip->setISOIndex(ISOIndex);
     }
 
     const auto gain = getCoreProperty(SJ_Gain).toDouble();
     if (gain != -1)
     {
-        commandProcessor.activeCCD->setGain(gain);
+        commandProcessor.data()->activeCCD->setGain(gain);
     }
 
     const auto offset = getCoreProperty(SJ_Offset).toDouble();
     if (offset != -1)
     {
-        commandProcessor.activeCCD->setOffset(offset);
+        commandProcessor.data()->activeCCD->setOffset(offset);
     }
 
-    if (stateMachine.targetFilterID != -1 && commandProcessor.activeFilterWheel != nullptr)
+    if (stateMachine->targetFilterID != -1 && commandProcessor.data()->activeFilterWheel != nullptr)
     {
-        if (stateMachine.targetFilterID != stateMachine.currentFilterID)
+        if (stateMachine->targetFilterID != stateMachine->m_CaptureState->currentFilterID)
         {
             emit prepareState(CAPTURE_CHANGING_FILTER);
 
@@ -447,28 +529,29 @@ CAPTUREResult SequenceJob::capture(bool autofocusReady, FITSMode mode)
             if (getCoreProperty(SequenceJob::SJ_Preview).toBool() || getFrameType() != FRAME_LIGHT || autofocusReady == false)
                 policy = static_cast<FilterManager::FilterPolicy>(policy & ~FilterManager::AUTOFOCUS_POLICY);
 
-            m_FilterManager->setFilterPosition(stateMachine.targetFilterID, policy);
+            m_FilterManager->setFilterPosition(stateMachine->targetFilterID, policy);
             return CAPTURE_FILTER_BUSY;
         }
     }
 
-    if (!stateMachine.guiderDriftOkForStarting())
+    if (!stateMachine->checkGuiderDriftForStarting())
     {
         emit prepareState(CAPTURE_GUIDER_DRIFT);
         return CAPTURE_GUIDER_DRIFT_WAIT;
     }
 
     // Only attempt to set ROI and Binning if CCD transfer format is FITS
-    if (commandProcessor.activeCCD->getTransferFormat() == ISD::CCD::FORMAT_FITS)
+    if (commandProcessor.data()->activeCCD->getEncodingFormat() == QLatin1String("FITS"))
     {
         int currentBinX = 1, currentBinY = 1;
-        commandProcessor.activeChip->getBinning(&currentBinX, &currentBinY);
+        commandProcessor.data()->activeChip->getBinning(&currentBinX, &currentBinY);
 
         const auto binning = getCoreProperty(SJ_Binning).toPoint();
         // N.B. Always set binning _before_ setting frame because if the subframed image
         // is problematic in 1x1 but works fine for 2x2, then it would fail it was set first
         // So setting binning first always ensures this will work.
-        if (commandProcessor.activeChip->canBin() && commandProcessor.activeChip->setBinning(binning.x(), binning.y()) == false)
+        if (commandProcessor.data()->activeChip->canBin()
+                && commandProcessor.data()->activeChip->setBinning(binning.x(), binning.y()) == false)
         {
             setStatus(JOB_ERROR);
             return CAPTURE_BIN_ERROR;
@@ -476,8 +559,8 @@ CAPTUREResult SequenceJob::capture(bool autofocusReady, FITSMode mode)
 
         const auto roi = getCoreProperty(SJ_ROI).toRect();
 
-        if ((roi.width() > 0 && roi.height() > 0) && commandProcessor.activeChip->canSubframe()
-                && commandProcessor.activeChip->setFrame(roi.x(),
+        if ((roi.width() > 0 && roi.height() > 0) && commandProcessor.data()->activeChip->canSubframe()
+                && commandProcessor.data()->activeChip->setFrame(roi.x(),
                         roi.y(),
                         roi.width(),
                         roi.height(),
@@ -488,28 +571,30 @@ CAPTUREResult SequenceJob::capture(bool autofocusReady, FITSMode mode)
         }
     }
 
-    commandProcessor.activeChip->setFrameType(getFrameType());
+    commandProcessor.data()->activeCCD->setCaptureFormat(getCoreProperty(SJ_Format).toString());
+    commandProcessor.data()->activeCCD->setEncodingFormat(getCoreProperty(SJ_Encoding).toString());
+    commandProcessor.data()->activeChip->setFrameType(getFrameType());
 
     // In case FITS Viewer is not enabled. Then for flat frames, we still need to keep the data
     // otherwise INDI CCD would simply discard loading the data in batch mode as the data are already
     // saved to disk and since no extra processing is required, FITSData is not loaded up with the data.
     // But in case of automatically calculated flat frames, we need FITSData.
     // Therefore, we need to explicitly set mode to FITS_CALIBRATE so that FITSData is generated.
-    commandProcessor.activeChip->setCaptureMode(mode);
-    commandProcessor.activeChip->setCaptureFilter(FITS_NONE);
+    commandProcessor.data()->activeChip->setCaptureMode(mode);
+    commandProcessor.data()->activeChip->setCaptureFilter(FITS_NONE);
 
     setStatus(getStatus());
 
     const auto exposure = getCoreProperty(SJ_Exposure).toDouble();
     m_ExposeLeft = exposure;
-    commandProcessor.activeChip->capture(exposure);
+    commandProcessor.data()->activeChip->capture(exposure);
 
     return CAPTURE_OK;
 }
 
 void SequenceJob::setTargetFilter(int pos, const QString &name)
 {
-    stateMachine.targetFilterID = pos;
+    stateMachine->targetFilterID = pos;
     setCoreProperty(SJ_Filter, name);
 }
 
@@ -523,12 +608,6 @@ void SequenceJob::setExposeLeft(double value)
     m_ExposeLeft = value;
 }
 
-void SequenceJob::setCurrentTemperature(double value)
-{
-    // forward it to the state machine
-    stateMachine.setCurrentCCDTemperature(value);
-}
-
 
 int SequenceJob::getCaptureRetires() const
 {
@@ -542,18 +621,13 @@ void SequenceJob::setCaptureRetires(int value)
 
 int SequenceJob::getCurrentFilter() const
 {
-    return stateMachine.currentFilterID;
+    return stateMachine->m_CaptureState->currentFilterID;
 }
 
 void SequenceJob::setCurrentFilter(int value)
 {
     // forward it to the state machine
-    stateMachine.setCurrentFilterID(value);
-}
-
-void SequenceJob::resetCurrentGuiderDrift()
-{
-    stateMachine.setCurrentGuiderDrift(1e8);
+    stateMachine->setCurrentFilterID(value);
 }
 
 // Setter: Set upload mode
@@ -570,22 +644,22 @@ ISD::CCD::UploadMode SequenceJob::getUploadMode() const
 // Setter: Set flat field source
 void SequenceJob::setFlatFieldSource(FlatFieldSource value)
 {
-    m_FlatFieldSource = value;
+    stateMachine->m_CaptureState->flatFieldSource = value;
 }
 // Getter: Get flat field source
 FlatFieldSource SequenceJob::getFlatFieldSource() const
 {
-    return m_FlatFieldSource;
+    return stateMachine->m_CaptureState->flatFieldSource;
 }
 
 void SequenceJob::setWallCoord(const SkyPoint &value)
 {
-    m_WallCoord = value;
+    stateMachine->m_CaptureState->wallCoord = value;
 }
 
 const SkyPoint &SequenceJob::getWallCoord() const
 {
-    return m_WallCoord;
+    return stateMachine->m_CaptureState->wallCoord;
 }
 
 // Setter: Set flat field duration
@@ -600,18 +674,6 @@ FlatFieldDuration SequenceJob::getFlatFieldDuration() const
     return m_FlatFieldDuration;
 }
 
-// Setter: Set transform format
-void SequenceJob::setTransferFormat(ISD::CCD::TransferFormat value)
-{
-    m_TransferFormat = value;
-}
-
-// Getter: Get transform format
-ISD::CCD::TransferFormat SequenceJob::getTransferFormat() const
-{
-    return m_TransferFormat;
-}
-
 void SequenceJob::setJobProgressIgnored(bool value)
 {
     m_JobProgressIgnored = value;
@@ -622,9 +684,45 @@ bool SequenceJob::getJobProgressIgnored() const
     return m_JobProgressIgnored;
 }
 
+void SequenceJob::setLightBox(ISD::LightBox *lightBox)
+{
+    // forward it to the command processor
+    commandProcessor.data()->setLightBox(lightBox);
+    stateMachine->m_CaptureState->hasLightBox = (lightBox != nullptr);
+}
+
+void SequenceJob::setDustCap(ISD::DustCap *dustCap)
+{
+    // forward it to the command processor
+    commandProcessor.data()->setDustCap(dustCap);
+    stateMachine->m_CaptureState->hasDustCap = (dustCap != nullptr);
+}
+
+void SequenceJob::setTelescope(ISD::Telescope *scope)
+{
+    // forward it to the command processor
+    commandProcessor.data()->setTelescope(scope);
+    stateMachine->m_CaptureState->hasTelescope = (scope != nullptr);
+}
+
+void SequenceJob::setDome(ISD::Dome *dome)
+{
+    // forward it to the command processor
+    commandProcessor.data()->setDome(dome);
+    stateMachine->m_CaptureState->hasDome = (dome != nullptr);
+}
+
+void SequenceJob::setFilterManager(const QSharedPointer<FilterManager> &manager)
+{
+    m_FilterManager = manager;
+    commandProcessor.data()->setFilterManager(manager);
+}
+
 void SequenceJob::setFrameType(CCDFrameType value)
 {
     m_FrameType = value;
+    // propagate the frame type to the state machine
+    stateMachine->setFrameType(value);
 }
 
 // Getter: Get Frame Type
@@ -643,13 +741,52 @@ QString SequenceJob::getSignature()
 
 }
 
-void SequenceJob::startPrepareCapture()
+void SequenceJob::prepareCapture()
 {
-    auto temperatureEnforced = getCoreProperty(SJ_EnforceTemperature).toBool();
-    auto preview = getCoreProperty(SequenceJob::SJ_Preview).toBool();
-    auto guiderActive = getCoreProperty(SJ_GuiderActive).toBool();
-    auto enforceGuiderDrift = getCoreProperty(SJ_EnforceStartGuiderDrift).toBool();
-    emit prepareCapture(getFrameType(), temperatureEnforced, guiderActive && enforceGuiderDrift, preview);
+    // create the event connections
+    connectCommandProcessor();
+    // simply forward it to the state machine
+    switch (getFrameType())
+    {
+        case FRAME_LIGHT:
+            stateMachine->prepareLightFrameCapture(getCoreProperty(SJ_EnforceTemperature).toBool(),
+                                                   getCoreProperty(SJ_Preview).toBool());
+            break;
+        case FRAME_FLAT:
+            stateMachine->prepareFlatFrameCapture(getCoreProperty(SJ_EnforceTemperature).toBool(),
+                                                  getCoreProperty(SJ_Preview).toBool());
+            break;
+        case FRAME_DARK:
+            stateMachine->prepareDarkFrameCapture(getCoreProperty(SJ_EnforceTemperature).toBool(),
+                                                  getCoreProperty(SJ_Preview).toBool());
+            break;
+        case FRAME_BIAS:
+            stateMachine->prepareBiasFrameCapture(getCoreProperty(SJ_EnforceTemperature).toBool(),
+                                                  getCoreProperty(SJ_Preview).toBool());
+            break;
+        default:
+            // not refactored yet, immediately completed
+            processPrepareComplete();
+            break;
+    }
+}
+
+void SequenceJob::processPrepareComplete()
+{
+    disconnectCommandProcessor();
+    emit prepareComplete();
+}
+
+void SequenceJob::processAbortCapture()
+{
+    disconnectCommandProcessor();
+    emit abortCapture();
+}
+
+IPState SequenceJob::checkFlatFramePendingTasksCompleted()
+{
+    // no further checks necessary
+    return IPS_OK;
 }
 
 void SequenceJob::setCoreProperty(PropertyID id, const QVariant &value)
