@@ -77,6 +77,7 @@ enum COMMANDS
     CAPTURE_GET_CALIBRATION_SETTINGS,
     CAPTURE_GET_FILE_SETTINGS,
     CAPTURE_LOOP,
+    CAPTURE_GENERATE_DARK_FLATS,
 
     // Mount
     MOUNT_PARK,
@@ -193,6 +194,22 @@ enum COMMANDS
     ASTRO_GET_OBJECTS_IMAGE,
     ASTRO_GET_OBJECTS_OBSERVABILITY,
     ASTRO_GET_OBJECTS_RISESET,
+
+    // Dark Library
+    DARK_LIBRARY_START,
+    DARK_LIBRARY_STOP,
+    DARK_LIBRARY_SET_CAMERA_PRESETS,
+    DARK_LIBRARY_GET_CAMERA_PRESETS,
+    DARK_LIBRARY_SET_SETTINGS,
+    DARK_LIBRARY_GET_DARK_SETTINGS,
+    DARK_LIBRARY_SET_DEFECT_SETTINGS,
+    DARK_LIBRARY_SET_DEFECT_PIXELS,
+    DARK_LIBRARY_GET_DEFECT_SETTINGS,
+    DARK_LIBRARY_SAVE_MAP,
+    DARK_LIBRARY_GET_VIEW_MASTERS,
+    DARK_LIBRARY_GET_MASTERS_IMAGE,
+    DARK_LIBRARY_CLEAR_MASTERS_ROW,
+    DARK_LIBRARY_SET_DEFECT_FRAME
 };
 
 static QMap<COMMANDS, QString> const commands =
@@ -257,6 +274,7 @@ static QMap<COMMANDS, QString> const commands =
     {CAPTURE_GET_CALIBRATION_SETTINGS, "capture_get_calibration_settings"},
     {CAPTURE_GET_FILE_SETTINGS, "capture_get_file_settings"},
     {CAPTURE_LOOP, "capture_loop"},
+    {CAPTURE_GENERATE_DARK_FLATS, "capture_generate_dark_flats"},
 
     {MOUNT_PARK, "mount_park"},
     {MOUNT_UNPARK, "mount_unpark"},
@@ -358,7 +376,22 @@ static QMap<COMMANDS, QString> const commands =
     {ASTRO_GET_OBJECTS_INFO, "astro_get_objects_info"},
     {ASTRO_GET_OBJECTS_IMAGE, "astro_get_objects_image"},
     {ASTRO_GET_OBJECTS_OBSERVABILITY, "astro_get_objects_observability"},
-    {ASTRO_GET_OBJECTS_RISESET, "astro_get_objects_riseset"}
+    {ASTRO_GET_OBJECTS_RISESET, "astro_get_objects_riseset"},
+
+    {DARK_LIBRARY_START, "dark_library_start"},
+    {DARK_LIBRARY_STOP, "dark_library_stop"},
+    {DARK_LIBRARY_SET_CAMERA_PRESETS, "dark_library_set_camera_presets"},
+    {DARK_LIBRARY_GET_CAMERA_PRESETS, "dark_library_get_camera_presets"},
+    {DARK_LIBRARY_SET_SETTINGS, "dark_library_set_settings"},
+    {DARK_LIBRARY_GET_DARK_SETTINGS, "dark_library_get_dark_settings"},
+    {DARK_LIBRARY_SET_DEFECT_SETTINGS, "dark_library_set_defect_settings"},
+    {DARK_LIBRARY_SET_DEFECT_PIXELS, "dark_library_set_defect_pixels"},
+    {DARK_LIBRARY_GET_DEFECT_SETTINGS, "dark_library_get_defect_settings"},
+    {DARK_LIBRARY_GET_VIEW_MASTERS, "dark_library_get_view_masters"},
+    {DARK_LIBRARY_GET_MASTERS_IMAGE, "dark_library_get_masters_image"},
+    {DARK_LIBRARY_CLEAR_MASTERS_ROW, "dark_library_clear_masters_row"},
+    {DARK_LIBRARY_SET_DEFECT_FRAME, "dark_library_set_defect_frame"},
+    {DARK_LIBRARY_SAVE_MAP, "dark_library_save_map"}
 };
 
 }
