@@ -13,6 +13,7 @@
 #include "fitsviewer/fitsview.h"
 #include "fitsviewer/fitsdata.h"
 #include "hips/hipsfinder.h"
+#include "ekos/auxiliary/darklibrary.h"
 #include "kspaths.h"
 #include "Options.h"
 
@@ -138,7 +139,7 @@ void Media::onTextReceived(const QString &message)
         for (auto &oneName : objectNames)
         {
             const QString name = oneName.toString();
-            SkyObject *oneObject = KStarsData::Instance()->skyComposite()->findByName(name);
+            SkyObject *oneObject = KStarsData::Instance()->skyComposite()->findByName(name, false);
             if (oneObject)
             {
                 QImage centerImage(HIPS_TILE_WIDTH, HIPS_TILE_HEIGHT, QImage::Format_ARGB32_Premultiplied);
@@ -515,5 +516,7 @@ void Media::sendModuleFrame(FITSView * view)
         sendPreviewImage(view, "+F");
     else if (qobject_cast<Ekos::Guide*>(sender()) == m_Manager->guideModule())
         sendPreviewImage(view, "+G");
+    else if (qobject_cast<Ekos::DarkLibrary*>(sender()) == Ekos::DarkLibrary::Instance())
+        sendPreviewImage(view, "+D");
 }
 }
