@@ -19,6 +19,7 @@
 #include "ksalmanac.h"
 #include "skymapcomposite.h"
 #include "catalogobject.h"
+#include "ekos/auxiliary/darklibrary.h"
 #include "skymap.h"
 #include "Options.h"
 
@@ -184,6 +185,8 @@ void Message::onTextReceived(const QString &message)
         processAstronomyCommands(command, payload);
     else if (command == commands[DIALOG_GET_RESPONSE])
         processDialogResponse(payload);
+    else if (command.startsWith("option_"))
+        processOptionsCommands(command, payload);
 
     if (m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
@@ -225,12 +228,12 @@ void Message::onTextReceived(const QString &message)
         processDomeCommands(command, payload);
     else if (command.startsWith("cap_"))
         processCapCommands(command, payload);
-    else if (command.startsWith("option_"))
-        processOptionsCommands(command, payload);
     else if (command.startsWith("dslr_"))
         processDSLRCommands(command, payload);
     else if (command.startsWith("fm_"))
         processFilterManagerCommands(command, payload);
+    else if (command.startsWith("dark_library_"))
+        processDarkLibraryCommands(command, payload);
     else if (command.startsWith("device_"))
         processDeviceCommands(command, payload);
 }
@@ -642,7 +645,8 @@ void Message::processCaptureCommands(const QString &command, const QJsonObject &
     }
     else if (command == commands[CAPTURE_REMOVE_SEQUENCE])
     {
-        capture->removeJob(payload["index"].toInt());
+        if (capture->removeJob(payload["index"].toInt()) == false)
+            sendCaptureSequence(capture->getSequence());
     }
     else if (command == commands[CAPTURE_SET_LIMITS])
     {
@@ -660,6 +664,10 @@ void Message::processCaptureCommands(const QString &command, const QJsonObject &
     {
         sendResponse(commands[CAPTURE_GET_FILE_SETTINGS], capture->getFileSettings());
     }
+    else if (command == commands[CAPTURE_GENERATE_DARK_FLATS])
+    {
+        capture->generateDarkFlats();
+    }
 }
 
 void Message::sendCaptureSequence(const QJsonArray &sequenceArray)
@@ -1246,6 +1254,70 @@ void Message::processFilterManagerCommands(const QString &command, const QJsonOb
     }
 }
 
+void Message::processDarkLibraryCommands(const QString &command, const QJsonObject &payload)
+{
+    if (command == commands[DARK_LIBRARY_START])
+    {
+        Ekos::DarkLibrary::Instance()->setDarkSettings(payload);
+        Ekos::DarkLibrary::Instance()->start();
+    }
+    else if(command == commands[DARK_LIBRARY_SET_SETTINGS])
+    {
+        Ekos::DarkLibrary::Instance()->setDarkSettings(payload);
+    }
+    else if(command == commands[DARK_LIBRARY_SET_CAMERA_PRESETS])
+    {
+        Ekos::DarkLibrary::Instance()->setCameraPresets(payload);
+    }
+    else if (command == commands[DARK_LIBRARY_STOP])
+    {
+        Ekos::DarkLibrary::Instance()->stop();
+    }
+    else if (command == commands[DARK_LIBRARY_GET_MASTERS_IMAGE])
+    {
+        const int row = payload["row"].toInt();
+        Ekos::DarkLibrary::Instance()->loadDarkImage(row);
+    }
+    else if (command == commands[DARK_LIBRARY_GET_DARK_SETTINGS])
+    {
+        sendResponse(commands[DARK_LIBRARY_GET_DARK_SETTINGS], Ekos::DarkLibrary::Instance()->getDarkSettings());
+    }
+    else if (command == commands[DARK_LIBRARY_GET_CAMERA_PRESETS])
+    {
+        sendResponse(commands[DARK_LIBRARY_GET_CAMERA_PRESETS], Ekos::DarkLibrary::Instance()->getCameraPresets());
+    }
+    else if (command == commands[DARK_LIBRARY_SET_DEFECT_PIXELS])
+    {
+        Ekos::DarkLibrary::Instance()->setDefectPixels(payload);
+    }
+    else if (command == commands[DARK_LIBRARY_SAVE_MAP])
+    {
+        Ekos::DarkLibrary::Instance()->saveMapB->click();
+    }
+    else if (command == commands[DARK_LIBRARY_SET_DEFECT_FRAME])
+    {
+        Ekos::DarkLibrary::Instance()->setDefectFrame(false);
+    }
+    else if (command == commands[DARK_LIBRARY_SET_DEFECT_SETTINGS])
+    {
+        Ekos::DarkLibrary::Instance()->setDefectSettings(payload);
+    }
+    else if (command == commands[DARK_LIBRARY_GET_DEFECT_SETTINGS])
+    {
+        sendResponse(commands[DARK_LIBRARY_GET_DEFECT_SETTINGS], Ekos::DarkLibrary::Instance()->getDefectSettings());
+    }
+    else if (command == commands[DARK_LIBRARY_GET_VIEW_MASTERS])
+    {
+        sendResponse(commands[DARK_LIBRARY_GET_VIEW_MASTERS], Ekos::DarkLibrary::Instance()->getViewMasters());
+    }
+    else if (command == commands[DARK_LIBRARY_CLEAR_MASTERS_ROW])
+    {
+        const int rowIndex = payload["row"].toInt();
+        Ekos::DarkLibrary::Instance()->clearRow(rowIndex);
+    }
+}
+
+
 void Message::processDeviceCommands(const QString &command, const QJsonObject &payload)
 {
     QList<ISD::GDInterface *> devices = m_Manager->getAllDevices();
@@ -1668,7 +1740,7 @@ void Message::processAstronomyCommands(const QString &command, const QJsonObject
         for (auto &oneName : objectNames)
         {
             const QString name = oneName.toString();
-            SkyObject *oneObject = KStarsData::Instance()->skyComposite()->findByName(name);
+            SkyObject *oneObject = KStarsData::Instance()->skyComposite()->findByName(name, false);
             if (oneObject)
             {
                 QJsonObject info =
@@ -1721,7 +1793,7 @@ void Message::processAstronomyCommands(const QString &command, const QJsonObject
         for (auto &oneName : objectNames)
         {
             const QString name = oneName.toString();
-            SkyObject *oneObject = data->skyComposite()->findByName(name);
+            SkyObject *oneObject = data->skyComposite()->findByName(name, false);
             if (oneObject)
             {
                 oneObject->EquatorialToHorizontal(data->lst(), geo->lat());
@@ -1768,7 +1840,7 @@ void Message::processAstronomyCommands(const QString &command, const QJsonObject
         for (auto &oneName : objectNames)
         {
             const QString name = oneName.toString();
-            SkyObject *oneObject = data->skyComposite()->findByName(name);
+            SkyObject *oneObject = data->skyComposite()->findByName(name, false);
             if (oneObject)
             {
                 QJsonObject info;
