@@ -145,6 +145,13 @@ QVector3D GuideStars::selectGuideStar(const QList<Edge> &stars,
                                       const QList<double> &minDistances)
 {
     constexpr int maxStarDiameter = 32;
+
+    if ((uint) stars.size() < Options::minDetectionsSEPMultistar())
+    {
+        qCDebug(KSTARS_EKOS_GUIDE) << "Too few stars detected.";
+        return QVector3D(-1, -1, -1);
+    }
+
     int maxIndex = MAX_GUIDE_STARS < stars.count() ? MAX_GUIDE_STARS : stars.count();
     int scores[MAX_GUIDE_STARS];
     QList<Edge> guideStarNeighbors;
@@ -257,6 +264,7 @@ void GuideStars::plotStars(GuideView *guideView, const QRect &trackingBox)
         guideView->addGuideStarNeighbor(offset.x() + reticle_x, offset.y() + reticle_y, found[i],
                                         detected_x, detected_y, isGuideStar);
     }
+    guideView->updateNeighbors();
 }
 
 // Find the guide star using the starCorrespondence algorithm (looking for
@@ -265,6 +273,13 @@ void GuideStars::plotStars(GuideView *guideView, const QRect &trackingBox)
 GuiderUtils::Vector GuideStars::findGuideStar(const QSharedPointer<FITSData> &imageData, const QRect &trackingBox,
         GuideView *guideView, bool firstFrame)
 {
+    // We fall-back to single star guiding if multistar isn't working,
+    // but limit this for a number of iterations.
+    // If a user doesn't have multiple stars available, the user shouldn't be using multistar.
+    constexpr int MAX_CONSECUTIVE_UNRELIABLE = 10;
+    if (firstFrame)
+        unreliableDectionCounter = 0;
+
     // Don't accept reference stars whose position is more than this many pixels from expected.
     constexpr double maxStarAssociationDistance = 10;
 
@@ -293,10 +308,7 @@ GuiderUtils::Vector GuideStars::findGuideStar(const QSharedPointer<FITSData> &im
             return GuiderUtils::Vector(-1, -1, -1);
 
         // Allow it to guide even if the main guide star isn't detected (as long as enough reference stars are).
-        constexpr int maxMissingGuideStars = 5;
-        starCorrespondence.setAllowMissingGuideStar(
-            allowMissingGuideStar &&
-            missedGuideStars < maxMissingGuideStars);
+        starCorrespondence.setAllowMissingGuideStar(allowMissingGuideStar);
 
         // Star correspondence can run quicker if it knows the image size.
         starCorrespondence.setImageSize(imageData->width(), imageData->height());
@@ -312,7 +324,7 @@ GuiderUtils::Vector GuideStars::findGuideStar(const QSharedPointer<FITSData> &im
                 double SNR = skyBackground.SNR(star.sum, star.numPixels);
                 guideStarSNR = SNR;
                 guideStarMass = star.sum;
-                missedGuideStars = 0;
+                unreliableDectionCounter = 0;
                 qCDebug(KSTARS_EKOS_GUIDE) << "StarCorrespondence found " << i << "at" << star.x << star.y << "SNR" << SNR;
                 if (guideView != nullptr)
                     plotStars(guideView, trackingBox);
@@ -327,7 +339,7 @@ GuiderUtils::Vector GuideStars::findGuideStar(const QSharedPointer<FITSData> &im
             double SNR = 0;
             guideStarSNR = SNR;
             guideStarMass = 0;
-            missedGuideStars++;
+            unreliableDectionCounter = 0;  // debating this
             qCDebug(KSTARS_EKOS_GUIDE) << "StarCorrespondence invented at" << position.x << position.y << "SNR" << SNR;
             if (guideView != nullptr)
                 plotStars(guideView, trackingBox);
@@ -336,6 +348,10 @@ GuiderUtils::Vector GuideStars::findGuideStar(const QSharedPointer<FITSData> &im
     }
 
     qCDebug(KSTARS_EKOS_GUIDE) << "StarCorrespondence not used. It failed to find the guide star.";
+
+    if (++unreliableDectionCounter > MAX_CONSECUTIVE_UNRELIABLE)
+        return GuiderUtils::Vector(-1, -1, -1);
+
     logStars("findGuide", "Star", skyBackground,
              detectedStars.size(),
              [&](int i) -> const Edge&
@@ -351,10 +367,35 @@ GuiderUtils::Vector GuideStars::findGuideStar(const QSharedPointer<FITSData> &im
         return GuiderUtils::Vector(-1, -1, -1);
 
     // If we didn't find a star that way, then fall back
-    findTopStars(imageData, 1, &detectedStars, maxHFR, &trackingBox);
+    findTopStars(imageData, 100, &detectedStars, maxHFR, &trackingBox);
     if (detectedStars.size() > 0)
     {
-        auto &star = detectedStars[0];
+        // Find the star closest to the guide star position, if we have a position.
+        // Otherwise use the center of the tracking box (which must be valid, see above if).
+        // 1. Get the guide star position
+        int best = 0;
+        double refX = trackingBox.x() + trackingBox.width() / 2;
+        double refY = trackingBox.y() + trackingBox.height() / 2;
+        if (starCorrespondence.size() > 0 && starCorrespondence.guideStar() >= 0)
+        {
+            const auto gStar = starCorrespondence.reference(starCorrespondence.guideStar());
+            refX = gStar.x;
+            refY = gStar.y;
+        }
+        // 2. Find the closest star to that position.
+        double minDistSq = 1e8;
+        for (int i = 0; i < detectedStars.size(); ++i)
+        {
+            const auto &dStar = detectedStars[i];
+            const double distSq = (dStar.x - refX) * (dStar.x - refX) + (dStar.y - refY) * (dStar.y - refY);
+            if (distSq < minDistSq)
+            {
+                best = i;
+                minDistSq = distSq;
+            }
+        }
+        // 3. Return that star.
+        auto &star = detectedStars[best];
         double SNR = skyBackground.SNR(star.sum, star.numPixels);
         guideStarSNR = SNR;
         guideStarMass = star.sum;
@@ -397,7 +438,7 @@ int GuideStars::findAllSEPStars(const QSharedPointer<FITSData> &imageData, QList
     // Let's sort edges, starting with widest
     std::sort(edges.begin(), edges.end(), [](const Edge * edge1, const Edge * edge2) -> bool { return edge1->HFR > edge2->HFR;});
 
-    // Take only the first maxNumCenters stars
+    // Take only the first num stars
     {
         int starCount = qMin(num, edges.count());
         for (int i = 0; i < starCount; i++)
@@ -486,8 +527,10 @@ void GuideStars::evaluateSEPStars(const QList<Edge *> &starCenters, QVector<doub
 {
     auto centers = starCenters;
     scores->clear();
-    for (int i = 0; i < centers.size(); ++i) scores->push_back(0);
-    if (centers.empty()) return;
+    const int numDetections = centers.size();
+    for (int i = 0; i < numDetections; ++i) scores->push_back(0);
+    if (numDetections == 0) return;
+
 
     // Rough constants used by this weighting.
     // If the center pixel is above this, assume it's clipped and don't emphasize.
@@ -502,14 +545,29 @@ void GuideStars::evaluateSEPStars(const QList<Edge *> &starCenters, QVector<doub
         double snrB = bg.SNR(b->sum, b->numPixels);
         return snrA < snrB;
     });
-    for (int i = 0; i < centers.size(); ++i)
+
+    // See if the HFR restriction is too severe.
+    int numRejectedByHFR = 0;
+    for (int i = 0; i < numDetections; ++i)
     {
-        for (int j = 0; j < starCenters.size(); ++j)
+        if (centers.at(i)->HFR > maxHFR)
+            numRejectedByHFR++;
+    }
+    const int starsRemaining = numDetections - numRejectedByHFR;
+    const bool useHFRConstraint =
+        starsRemaining > 5    ||
+        (starsRemaining >= 3 && numDetections <= 6) ||
+        (starsRemaining >= 2 && numDetections <= 4) ||
+        (starsRemaining >= 1 && numDetections <= 2);
+
+    for (int i = 0; i < numDetections; ++i)
+    {
+        for (int j = 0; j < numDetections; ++j)
         {
             if (starCenters.at(j) == centers.at(i))
             {
                 // Don't emphasize stars that are too wide.
-                if (centers.at(i)->HFR > maxHFR)
+                if (useHFRConstraint && centers.at(i)->HFR > maxHFR)
                     (*scores)[j] = -1;
                 else
                     (*scores)[j] += snrWeight * i;
