@@ -12,6 +12,7 @@
 #include "ui_scheduler.h"
 #include "ekos/align/align.h"
 #include "indi/indiweather.h"
+#include "ekos/auxiliary/solverutils.h"
 #include "schedulerjob.h"
 
 #include <lilxml.h>
@@ -38,6 +39,7 @@ namespace Ekos
 {
 
 class SequenceJob;
+class GreedyScheduler;
 
 /**
  * @brief The Ekos scheduler is a simple scheduler class to orchestrate automated multi object observation jobs.
@@ -102,6 +104,13 @@ class Scheduler : public QWidget, public Ui::Scheduler
             ERROR_RESTART_IMMEDIATELY
         } ErrorHandlingStrategy;
 
+        /** @brief Algorithms, in the same order as UI. */
+        typedef enum
+        {
+            ALGORITHM_CLASSIC,
+            ALGORITHM_GREEDY
+        } SchedulerAlgorithm;
+
         /** @brief Columns, in the same order as UI. */
         typedef enum
         {
@@ -130,7 +139,8 @@ class Scheduler : public QWidget, public Ui::Scheduler
         /** @brief Constructor, the starndard scheduler constructor. */
         Scheduler();
         /** @brief DebugConstructor, a constructor used in testing with a mock ekos. */
-        Scheduler(const QString &ekosPathStr, const QString &ekosInterfaceStr);
+        Scheduler(const QString path, const QString interface,
+                  const QString &ekosPathStr, const QString &ekosInterfaceStr);
         ~Scheduler() = default;
 
         QString getCurrentJobName();
@@ -297,19 +307,30 @@ class Scheduler : public QWidget, public Ui::Scheduler
         /**
              * @brief evaluateJobs Computes estimated start and end times for the SchedulerJobs passed in. Returns a proposed schedule.
              * @param jobs The input list of SchedulerJobs to evaluate.
-             * @param state The current scheduler state.
              * @param capturedFramesCount which parts of the schedulerJobs have already been completed.
              * @param dawn next dawn, as a KStarsDateTime
              * @param dusk next dusk, as a KStarsDateTime
+             * @param scheduler instance of the scheduler used for logging. Can be nullptr.
+             * @return list of sorted jobs
+             */
+        static QList<SchedulerJob *> evaluateJobs(QList<SchedulerJob *> &jobs, const QMap<QString, uint16_t> &capturedFramesCount,
+                QDateTime const &dawn, QDateTime const &dusk, Scheduler *scheduler);
+
+        /**
+             * @brief prepareJobsForEvaluation Start of job evaluation
+             * @param jobs The input list of SchedulerJobs to evaluate.
+             * @param state The current scheduler state.
+             * @param capturedFramesCount which parts of the schedulerJobs have already been completed.
              * @param rescheduleErrors whether jobs that failed with errors should be rescheduled.
              * @param restartJobs whether jobs that failed for one reason or another shoulc be rescheduled.
              * @param possiblyDelay a return value indicating whether the timer should try scheduling again after a delay.
              * @param scheduler instance of the scheduler used for logging. Can be nullptr.
              * @return Total score
              */
-        static QList<SchedulerJob *> evaluateJobs(QList<SchedulerJob *> &jobs, SchedulerState state,
-                const QMap<QString, uint16_t> &capturedFramesCount, QDateTime const &dawn, QDateTime const &dusk,
-                bool rescheduleErrors, bool restartJobs, bool *possiblyDelay, Scheduler *scheduler);
+        static QList<SchedulerJob *> prepareJobsForEvaluation(
+            QList<SchedulerJob *> &jobs, SchedulerState state, const QMap<QString, uint16_t> &capturedFramesCount,
+            bool rescheduleErrors, bool restartJobs, bool *possiblyDelay, Scheduler *scheduler);
+
         /**
              * @brief calculateJobScore Calculate job dark sky score, altitude score, and moon separation scores and returns the sum.
              * @param job Target
@@ -317,7 +338,9 @@ class Scheduler : public QWidget, public Ui::Scheduler
              * @param dusk next dusk, as a KStarsDateTime
              * @param when date and time to evaluate constraints, now if omitted.
              * @return Total score
+             *
              */
+
         static int16_t calculateJobScore(SchedulerJob const *job, QDateTime const &dawn, QDateTime const &dusk,
                                          QDateTime const &when = QDateTime());
 
@@ -363,6 +386,14 @@ class Scheduler : public QWidget, public Ui::Scheduler
         }
         /** @} */
 
+        void setUpdateInterval(int ms)
+        {
+            m_UpdatePeriodMs = ms;
+        }
+        int getUpdateInterval()
+        {
+            return m_UpdatePeriodMs;
+        }
     private:
         /**
              * @brief processJobInfo a utility used by loadSequenceQueue() to help it read a capture sequence file
@@ -379,6 +410,9 @@ class Scheduler : public QWidget, public Ui::Scheduler
              */
         static int timeHeuristics(const SchedulerJob *schedJob);
 
+        void setAlgorithm(int alg);
+        SchedulerAlgorithm getAlgorithm() const;
+
         // Used in testing, instead of KStars::Instance() resources
         static KStarsDateTime *storedLocalTime;
 
@@ -579,6 +613,8 @@ class Scheduler : public QWidget, public Ui::Scheduler
              * @brief checkJobStage Check the progress of the job states and make DBUS call to start the next stage until the job is complete.
              */
         void checkJobStage();
+        bool checkJobStageClassic();
+        void checkJobStageEplogue();
 
         /**
              * @brief findNextJob Check if the job met the completion criteria, and if it did, then it search for next job candidate. If no jobs are found, it starts the shutdown stage.
@@ -649,13 +685,32 @@ class Scheduler : public QWidget, public Ui::Scheduler
         void simClockScaleChanged(float);
         void simClockTimeChanged();
 
+        /**
+         * @brief solverDone Process solver solution after it is done.
+         * @param timedOut True if the process timed out.
+         * @param success True if successful, false otherwise.
+         * @param solution The solver solution if successful.
+         * @param elapsedSeconds How many seconds elapsed to solve the image.
+         */
+        void solverDone(bool timedOut, bool success, const FITSImage::Solution &solution, double elapsedSeconds);
+
+        /**
+         * @brief setCaptureComplete Handle one sequence image completion. This is used now only to run alignment check
+         * to ensure it does not deviation from current scheduler job target.
+         * @param metadata Metadata for image including filename, exposure, filter, hfr..etc.
+         */
+        void setCaptureComplete(const QVariantMap &metadata);
+
     signals:
         void newLog(const QString &text);
         void newStatus(Ekos::SchedulerState state);
         void weatherChanged(ISD::Weather::Status state);
         void newTarget(const QString &);
+        // Below 2 are for the Analyze timeline.
+        void jobStarted(const QString &jobName);
+        void jobEnded(const QString &jobName, const QString &endReason);
 
-private:
+    private:
         /**
              * @brief evaluateJobs evaluates the current state of each objects and gives each one a score based on the constraints.
              * Given that score, the scheduler will decide which is the best job that needs to be executed.
@@ -825,7 +880,8 @@ private:
          * @param framesCount map capture signature -> frame count
          * @return true iff the job need to capture light frames
          */
-        void updateLightFramesRequired(SchedulerJob *oneJob, const QList<SequenceJob *> &seqjobs, const SchedulerJob::CapturedFramesMap &framesCount);
+        void updateLightFramesRequired(SchedulerJob *oneJob, const QList<SequenceJob *> &seqjobs,
+                                       const SchedulerJob::CapturedFramesMap &framesCount);
 
         /**
          * @brief Calculate the map signature -> expected number of captures from the given list of capture sequence jobs,
@@ -846,7 +902,8 @@ private:
          *        of the scheduler job creates as many frames as possible, but does not exceed the expected ones.
          * @return total number of captured frames, truncated to the maximal number of frames the scheduler job could produce
          */
-        static uint16_t fillCapturedFramesMap(const QMap<QString, uint16_t> &expected, const SchedulerJob::CapturedFramesMap &capturedFramesCount,
+        static uint16_t fillCapturedFramesMap(const QMap<QString, uint16_t> &expected,
+                                              const SchedulerJob::CapturedFramesMap &capturedFramesCount,
                                               SchedulerJob &schedJob, SchedulerJob::CapturedFramesMap &capture_map);
 
         int getCompletedFiles(const QString &path, const QString &seqPrefix);
@@ -878,6 +935,9 @@ private:
         QPointer<QDBusInterface> capInterface { nullptr };
 
         // Interface strings for the dbus. Changeable for mocks when testing. Private so only tests can change.
+        QString schedulerPathString { "/KStars/Ekos/Scheduler" };
+        QString kstarsInterfaceString { "org.kde.kstars" };
+
         QString focusInterfaceString { "org.kde.kstars.Ekos.Focus" };
         void setFocusInterfaceString(const QString &interface)
         {
@@ -1091,10 +1151,7 @@ private:
         // This is the time between typical scheduler iterations.
         // The time can be modified for testing.
         int m_UpdatePeriodMs = 1000;
-        void setUpdateInterval(int ms)
-        {
-            m_UpdatePeriodMs = ms;
-        }
+
         // Setup the parameters for the next scheduler iteration.
         // When milliseconds is not passed in, it uses m_UpdatePeriodMs.
         void setupNextIteration(SchedulerTimerState nextState);
@@ -1122,6 +1179,23 @@ private:
         // The time when the scheduler first started running iterations.
         qint64 startMSecs { 0 };
 
+        /// Target coordinates for pointing check
+        std::unique_ptr<SolverUtils> m_Solver;
+        // Used when solving position every nth capture.
+        uint32_t m_SolverIteration {0};
+
+        void syncGreedyParams();
+        QPointer<Ekos::GreedyScheduler> m_GreedyScheduler;
+
         friend TestEkosSchedulerOps;
+        // Only for testing
+        QList<SchedulerJob *> &getJobs()
+        {
+            return jobs;
+        }
+        QPointer<GreedyScheduler> &getGreedyScheduler()
+        {
+            return m_GreedyScheduler;
+        }
 };
 }
