@@ -68,6 +68,9 @@ FITSView *CCDChip::getImageView(FITSMode imageType)
 
         case FITS_ALIGN:
             return alignImage;
+
+        default:
+            break;
     }
 
     return nullptr;
@@ -96,6 +99,9 @@ void CCDChip::setImageView(FITSView *image, FITSMode imageType)
         case FITS_ALIGN:
             alignImage = image;
             break;
+
+        default:
+            break;
     }
 
     if (image)
@@ -934,16 +940,30 @@ void CCD::registerProperty(INDI::Property prop)
         // Has Video Stream
         HasVideoStream = true;
     }
+    else if (prop->isNameMatch("CCD_CAPTURE_FORMAT"))
+    {
+        auto sp = prop->getSwitch();
+        if (sp)
+        {
+            m_CaptureFormats.clear();
+            for (const auto &oneSwitch : *sp)
+                m_CaptureFormats << oneSwitch.getLabel();
+
+            m_CaptureFormatIndex = sp->findOnSwitchIndex();
+        }
+    }
     else if (prop->isNameMatch("CCD_TRANSFER_FORMAT"))
     {
         auto sp = prop->getSwitch();
         if (sp)
         {
-            auto format = sp->findWidgetByName("FORMAT_NATIVE");
-            if (format && format->getState() == ISS_ON)
-                transferFormat = FORMAT_NATIVE;
-            else
-                transferFormat = FORMAT_FITS;
+            m_EncodingFormats.clear();
+            for (const auto &oneSwitch : *sp)
+                m_EncodingFormats << oneSwitch.getLabel();
+
+            auto format = sp->findOnSwitch();
+            if (format)
+                m_EncodingFormat = format->label;
         }
     }
     else if (prop->isNameMatch("CCD_EXPOSURE_PRESETS"))
@@ -1206,14 +1226,21 @@ void CCD::processSwitch(ISwitchVectorProperty *svp)
             emit videoStreamToggled(svp->sp[0].s == ISS_ON);
         }
     }
+    else if (!strcmp(svp->name, "CCD_CAPTURE_FORMAT"))
+    {
+        m_CaptureFormats.clear();
+        for (int i = 0; i < svp->nsp; i++)
+        {
+            m_CaptureFormats << svp->sp[i].label;
+            if (svp->sp[i].s == ISS_ON)
+                m_CaptureFormatIndex = i;
+        }
+    }
     else if (!strcmp(svp->name, "CCD_TRANSFER_FORMAT"))
     {
-        ISwitch *format = IUFindSwitch(svp, "FORMAT_NATIVE");
-
-        if (format && format->s == ISS_ON)
-            transferFormat = FORMAT_NATIVE;
-        else
-            transferFormat = FORMAT_FITS;
+        ISwitch *format = IUFindOnSwitch(svp);
+        if (format)
+            m_EncodingFormat = format->label;
     }
     else if (!strcmp(svp->name, "RECORD_STREAM"))
     {
@@ -1242,20 +1269,25 @@ void CCD::processSwitch(ISwitchVectorProperty *svp)
     {
         m_FastExposureEnabled = IUFindOnSwitchIndex(svp) == 0;
     }
-    else if (streamWindow && !strcmp(svp->name, "CONNECTION"))
+    else if (!strcmp(svp->name, "CONNECTION"))
     {
         ISwitch *dSwitch = IUFindSwitch(svp, "DISCONNECT");
 
         if (dSwitch && dSwitch->s == ISS_ON)
         {
-            streamWindow->enableStream(false);
-            emit videoStreamToggled(false);
-            streamWindow->close();
-            streamWindow.reset();
-        }
+            if (streamWindow)
+            {
+                streamWindow->enableStream(false);
+                emit videoStreamToggled(false);
+                streamWindow->close();
+                streamWindow.reset();
+            }
 
-        //emit switchUpdated(svp);
-        //return;
+            // Clear the pointers on disconnect.
+            gainN = nullptr;
+            offsetN = nullptr;
+            primaryCCDBLOB = nullptr;
+        }
     }
 
     DeviceDecorator::processSwitch(svp);
@@ -1456,6 +1488,7 @@ void CCD::processBLOB(IBLOB *bp)
     if (BType == BLOB_OTHER)
     {
         DeviceDecorator::processBLOB(bp);
+        emit newImage(nullptr);
         return;
     }
 
@@ -1747,16 +1780,6 @@ void CCD::loadImageInView(ISD::CCDChip *targetChip, const QSharedPointer<FITSDat
     }
 }
 
-CCD::TransferFormat CCD::getTargetTransferFormat() const
-{
-    return targetTransferFormat;
-}
-
-void CCD::setTargetTransferFormat(const TransferFormat &value)
-{
-    targetTransferFormat = value;
-}
-
 //void CCD::FITSViewerDestroyed()
 //{
 //    normalTabID = calibrationTabID = focusTabID = guideTabID = alignTabID = -1;
@@ -2054,9 +2077,9 @@ bool CCD::setTemperature(double value)
     return true;
 }
 
-bool CCD::setTransformFormat(CCD::TransferFormat format)
+bool CCD::setEncodingFormat(const QString &value)
 {
-    if (format == transferFormat)
+    if (value == m_EncodingFormat)
         return true;
 
     auto svp = baseDevice->getSwitch("CCD_TRANSFER_FORMAT");
@@ -2064,19 +2087,18 @@ bool CCD::setTransformFormat(CCD::TransferFormat format)
     if (!svp)
         return false;
 
-    auto formatFITS   = svp->findWidgetByName("FORMAT_FITS");
-    auto formatNative = svp->findWidgetByName("FORMAT_NATIVE");
-
-    if (!formatFITS || !formatNative)
-        return false;
-
-    transferFormat = format;
-
-    formatFITS->setState(transferFormat == FORMAT_FITS ? ISS_ON : ISS_OFF);
-    formatNative->setState(transferFormat == FORMAT_FITS ? ISS_OFF : ISS_ON);
+    svp->reset();
+    for (int i = 0; i < svp->nsp; i++)
+    {
+        if (svp->at(i)->getLabel() == value)
+        {
+            svp->at(i)->setState(ISS_ON);
+            break;
+        }
+    }
 
+    m_EncodingFormat = value;
     clientManager->sendNewSwitch(svp);
-
     return true;
 }
 
@@ -2504,6 +2526,19 @@ bool CCD::setFastExposureEnabled(bool enable)
     return true;
 }
 
+bool CCD::setCaptureFormat(const QString &format)
+{
+    auto svp = baseDevice->getSwitch("CCD_CAPTURE_FORMAT");
+    if (!svp)
+        return false;
+
+    for (auto &oneSwitch : *svp)
+        oneSwitch.setState(oneSwitch.label == format ? ISS_ON : ISS_OFF);
+
+    clientManager->sendNewSwitch(svp);
+    return true;
+}
+
 bool CCD::setFastCount(uint32_t count)
 {
     auto nvp = baseDevice->getNumber("CCD_FAST_COUNT");
@@ -2607,4 +2642,12 @@ bool CCD::WriteImageFileInternal(const QString &filename, char *buffer, const si
                         QFileDevice::ReadOther);
     return ok;
 }
+
+QString CCD::getCaptureFormat() const
+{
+    if (m_CaptureFormatIndex < 0 || m_CaptureFormats.isEmpty() || m_CaptureFormatIndex > m_CaptureFormats.size())
+        return QLatin1String("NA");
+
+    return m_CaptureFormats[m_CaptureFormatIndex];
+}
 }
