@@ -44,6 +44,15 @@ Telescope::Telescope(GDInterface *iPtr) : DeviceDecorator(iPtr)
     readyTimer.setSingleShot(true);
     connect(&readyTimer, &QTimer::timeout, this, &Telescope::ready);
 
+    // Regularly update the coordinates even if no update has been sent from the INDI service
+    updateCoordinatesTimer.setInterval(1000);
+    updateCoordinatesTimer.setSingleShot(false);
+    connect(&updateCoordinatesTimer, &QTimer::timeout, this, [this]()
+    {
+        if (isConnected())
+            emit newCoords(currentCoords, pierSide(), hourAngle());
+    });
+
     qRegisterMetaType<ISD::Telescope::Status>("ISD::Telescope::Status");
     qDBusRegisterMetaType<ISD::Telescope::Status>();
 
@@ -196,6 +205,7 @@ void Telescope::registerProperty(INDI::Property prop)
     else if (prop->isNameMatch("EQUATORIAL_EOD_COORD"))
     {
         m_isJ2000 = false;
+        m_hasEquatorialCoordProperty = true;
     }
     else if (prop->isNameMatch("SAT_TRACKING_STAT"))
     {
@@ -204,6 +214,7 @@ void Telescope::registerProperty(INDI::Property prop)
     else if (prop->isNameMatch("EQUATORIAL_COORD"))
     {
         m_isJ2000 = true;
+        m_hasEquatorialCoordProperty = true;
     }
 
     DeviceDecorator::registerProperty(prop);
@@ -245,7 +256,9 @@ void Telescope::processNumber(INumberVectorProperty *nvp)
         // calculate horizontal coordinates
         currentCoords.EquatorialToHorizontal(KStars::Instance()->data()->lst(),
                                              KStars::Instance()->data()->geo()->lat());
-        emit newCoords(currentCoords, pierSide(), hourAngle());
+        // ensure that coordinates are regularly updated
+        if (! updateCoordinatesTimer.isActive())
+            updateCoordinatesTimer.start();
 
         ISD::Telescope::Status currentStatus = status(nvp);
 
@@ -268,7 +281,11 @@ void Telescope::processNumber(INumberVectorProperty *nvp)
 
         KStars::Instance()->map()->update();
     }
-    else if (!strcmp(nvp->name, "HORIZONTAL_COORD"))
+    // JM 2022.03.11 Only process HORIZONTAL_COORD if it was the ONLY source of information
+    // When a driver both sends EQUATORIAL_COORD and HORIZONTAL_COORD, we should prioritize EQUATORIAL_COORD
+    // especially since the conversion from horizontal to equatorial is not as accurate and can result in weird
+    // coordinates near the poles.
+    else if (!strcmp(nvp->name, "HORIZONTAL_COORD") && m_hasEquatorialCoordProperty == false)
     {
         INumber *Az  = IUFindNumber(nvp, "AZ");
         INumber *Alt = IUFindNumber(nvp, "ALT");
@@ -280,12 +297,24 @@ void Telescope::processNumber(INumberVectorProperty *nvp)
         currentCoords.setAlt(Alt->value);
         currentCoords.HorizontalToEquatorial(KStars::Instance()->data()->lst(),
                                              KStars::Instance()->data()->geo()->lat());
+
         // calculate J2000 coordinates
         updateJ2000Coordinates(&currentCoords);
 
-        emit newCoords(currentCoords, pierSide(), hourAngle());
+        // ensure that coordinates are regularly updated
+        if (! updateCoordinatesTimer.isActive())
+            updateCoordinatesTimer.start();
+
         KStars::Instance()->map()->update();
     }
+    else if (!strcmp(nvp->name, "POLLING_PERIOD"))
+    {
+        // set the timer how often the coordinates should be published
+        INumber *period = IUFindNumber(nvp, "PERIOD_MS");
+        if (period != nullptr)
+            updateCoordinatesTimer.setInterval(static_cast<int>(period->value));
+
+    }
 
     DeviceDecorator::processNumber(nvp);
 }
