@@ -1,26 +1,13 @@
-/***************************************************************************
-                          conjunctions.cpp  -  Conjunctions Tool
-                             -------------------
-    begin                : Sun 20th Apr 2008
-    copyright            : (C) 2008 Akarsh Simha
-    email                : akarshsimha@gmail.com
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Akarsh Simha <akarshsimha@gmail.com>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/***************************************************************************
- *                                                                         *
- * Much of the code here is taken from Pablo de Vicente's                  *
- * modcalcplanets.cpp                                                      *
- *                                                                         *
- ***************************************************************************/
+
+    Much of the code here is taken from Pablo de Vicente's
+    modcalcplanets.cpp
+
+*/
 
 #include "conjunctions.h"
 
